pub struct ProfileFile {
pub root_path: NonEmptyString,
pub path: NonEmptyString,
pub sha256: NonEmptyString,
pub content: String,
}Expand description
A resolved profile sourced from a workspace file (memory, conventions, voice).
Fields
root_path: NonEmptyStringpath: NonEmptyStringsha256: NonEmptyStringcontent: StringTrait Implementations
Sourceimpl Clone for ProfileFile
impl Clone for ProfileFile
Sourcefn clone(&self) -> ProfileFile
fn clone(&self) -> ProfileFile
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProfileFile
impl Debug for ProfileFile
Sourceimpl<'de> Deserialize<'de> for ProfileFile
impl<'de> Deserialize<'de> for ProfileFile
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ProfileFile
Sourceimpl PartialEq for ProfileFile
impl PartialEq for ProfileFile
Sourcefn eq(&self, other: &ProfileFile) -> bool
fn eq(&self, other: &ProfileFile) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl RunxSchema for ProfileFile
impl RunxSchema for ProfileFile
Sourcefn json_schema() -> Value
fn json_schema() -> Value
The inlined JSON Schema for this type.
Sourceimpl Serialize for ProfileFile
impl Serialize for ProfileFile
impl StructuralPartialEq for ProfileFile